==> detecty-0.0.7-py3-none-any.whl: detecty/util.py <==
from pathlib import Path

import torch
from PIL import Image, ImageDraw, ImageFile
from torch import Tensor
from torchvision.transforms.functional import (pad, resize, to_grayscale,
                                               to_tensor)

from detecty.bbox import Bbox

ImageFile.LOAD_TRUNCATED_IMAGES = True


def load_img(path: str | Path):
    return to_grayscale_tensor(Image.open(path))


def load_imgs_from_folder(folder: str | Path):
    folder = Path(folder)

    for path in folder.glob('*.jpg'):
        yield path, load_img(path)

    for path in folder.glob('*.JPG'):
        yield path, load_img(path)

    for path in folder.glob('*.jpeg'):
        yield path, load_img(path)

    for path in folder.glob('*.JPEG'):
        yield path, load_img(path)

    for path in folder.glob('*.png'):
        yield path, load_img(path)

    for path in folder.glob('*.PNG'):
        yield path, load_img(path)

    for path in folder.glob('*.bmp'):
        yield path, load_img(path)

    for path in folder.glob('*.BMP'):
        yield path, load_img(path)


def draw_bbox(img: Image.Image, *bboxs: Bbox):
    img = img.convert('RGB')
    draw = ImageDraw.Draw(img)
    colors = ['red', 'green', 'blue', 'yellow', 'purple', 'orange']
    for color, bb in zip(colors, bboxs):
        draw.rectangle(
            (bb.x1, bb.y1, bb.x2, bb.y2),
            outline=color,
            width=3)

    return img


def to_grayscale_tensor(img: Image.Image):
    return to_tensor(to_grayscale(img))


def pad_square(img: Tensor):
    _, h, w = img.shape

    if h == w:
        return img

    if h > w:
        return pad(img, [0, 0, h-w, 0])

    return pad(img, [0, 0, 0, w-h])


def resize_square(img: Tensor, target_size=256):
    _, h, w = img.shape

    assert h == w, f'Image is not square: {h} != {w}'

    img = resize(img, [target_size, target_size], antialias=True)

    return img


def pad_resize_scale_bb(img: Tensor, bb: Bbox, target_size=256):
    img = pad_square(img)
    _, h, w = img.shape
    scale = target_size / h
    img = resize_square(img, target_size)

    return img, bb.scale(scale).tensor


def crop(*, img: Tensor, bb: Tensor, padding=.3):
    x1, y1, x2, y2 = bb.to(torch.int)
    w, h = x2 - x1, y2 - y1
    x1 -= int(w * padding)
    y1 -= int(h * padding)
    x2 += int(w * padding)
    y2 += int(h * padding)

    return img[..., y1:y2, x1:x2]


def clear_tmp():
    from os import mkdir
    from shutil import rmtree
    rmtree('tmp', ignore_errors=True)
    mkdir('tmp')

==> detecty-0.0.18-py3-none-any.whl: detecty/util.py <==
from pathlib import Path

from PIL import Image, ImageDraw, ImageFile
from torch import Tensor
from torchvision.transforms.functional import (pad, resize, to_grayscale,
                                               to_tensor)

from detecty.bbox import BBox

ImageFile.LOAD_TRUNCATED_IMAGES = True

TARGET_SIZE = 256


def draw_bbox(img: Image.Image, *bboxs: BBox):
    img = img.convert('RGB')
    draw = ImageDraw.Draw(img)
    colors = ['red', 'green', 'blue', 'yellow', 'purple', 'orange']
    for color, bb in zip(colors, bboxs):
        draw.rectangle(
            (bb.x1, bb.y1, bb.x2, bb.y2),
            outline=color,
            width=1)

    return img


def to_grayscale_tensor(img: Image.Image):
    return to_tensor(to_grayscale(img))


def load_img(path: str | Path):
    return to_grayscale_tensor(Image.open(path))


def scale_target_size(img: Tensor, ratio: float):
    if ratio == 1:
        return img

    _, h, w = img.shape

    return resize(
        img,
        [round(h * ratio), round(w * ratio)],
        antialias=True)


def pad_square(img: Tensor):
    _, h, w = img.shape

    if h == w:
        return img

    if h > w:
        return pad(img, [0, 0, h-w, 0])

    return pad(img, [0, 0, 0, w-h])


def scale_pad_square(img: Tensor):
    _, h, w = img.shape
    ratio = TARGET_SIZE / max(h, w)

    img = scale_target_size(img, ratio)
    img = pad_square(img)

    assert img.shape == (
        1, TARGET_SIZE, TARGET_SIZE), f'Expected (1, {TARGET_SIZE}, {TARGET_SIZE}), got {img.shape}'

    return ratio, img


def clear_tmp():
    from os import mkdir
    from shutil import rmtree
    rmtree('tmp', ignore_errors=True)
    mkdir('tmp')
